@@ -12,7 +12,7 @@ from koapy.utils.logging import set_verbosity
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
-client_check_timeout = 3
+client_check_timeout = 10
 
 def fail_with_usage(message=None):
     ctx = click.get_current_context()
@@ -42,16 +42,16 @@ def serve(port, verbose, no_verbose, args):
     if not no_verbose and verbose > 0:
         app_args.append('-' + 'v' * verbose)
     app_args += list(args)
-    from koapy.pyside2.KiwoomOpenApiTrayApplication import KiwoomOpenApiTrayApplication
-    KiwoomOpenApiTrayApplication.main(app_args)
+    from koapy import KiwoomOpenApiPlusTrayApplication
+    KiwoomOpenApiPlusTrayApplication.main(app_args)
 
 @cli.command(context_settings=CONTEXT_SETTINGS, short_help='Ensure logged in when server is up.')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
 def login(port, verbose):
     set_verbosity(verbose)
-    from koapy import KiwoomOpenApiContext
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout) as context:
         state = context.GetConnectState()
         if state == 0:
             click.echo('Logging in...')
@@ -73,8 +73,8 @@ def config():
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
 def autologin(port, verbose):
     set_verbosity(verbose)
-    from koapy import KiwoomOpenApiContext
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout) as context:
         context.EnsureConnected()
         context.ShowAccountWindow()
 
@@ -83,24 +83,28 @@ def update():
     pass
 
 @update.command(context_settings=CONTEXT_SETTINGS, short_help='Update openapi TR metadata.')
-@click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def trdata(port, verbose):
+def trdata(verbose):
     set_verbosity(verbose)
-    from koapy import KiwoomOpenApiContext
-    from koapy.openapi.TrInfo import TrInfo
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
-        TrInfo.dump_trinfo_by_code(context=context)
+    from koapy import KiwoomOpenApiPlusTrInfo
+    KiwoomOpenApiPlusTrInfo.dump_trinfo_by_code()
 
 @update.command(context_settings=CONTEXT_SETTINGS, short_help='Update openapi realtype metadata.')
-@click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def realdata(port, verbose):
+def realdata(verbose):
     set_verbosity(verbose)
-    from koapy import KiwoomOpenApiContext
-    from koapy.openapi.RealType import RealType
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
-        RealType.dump_realtype_by_desc(context=context)
+    from koapy import KiwoomOpenApiPlusRealType
+    KiwoomOpenApiPlusRealType.dump_realtype_by_desc()
+
+@update.command(context_settings=CONTEXT_SETTINGS, short_help='Update openapi version.')
+@click.option('-v', '--verbose', count=True, help='Verbosity.')
+def version(verbose):
+    set_verbosity(verbose)
+    from koapy import KiwoomOpenApiPlusVersionUpdater
+    from koapy.config import config
+    credential = config.get('koapy.backend.kiwoom_open_api_plus.credential')
+    updater = KiwoomOpenApiPlusVersionUpdater(credential)
+    updater.update_version_if_necessary()
 
 @cli.group(context_settings=CONTEXT_SETTINGS, short_help='Get various types of data.')
 def get():
@@ -150,9 +154,9 @@ def stockcode(names, markets, port):
         # fail_with_usage()
         pass
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout) as context:
         context.EnsureConnected()
 
         if not names and not markets:
@@ -207,9 +211,9 @@ def stockcode(names, markets, port):
 @click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 def stockname(codes, port):
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout) as context:
         context.EnsureConnected()
 
         def get_codes():
@@ -238,71 +242,19 @@ def stockname(codes, port):
             click.echo(name)
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get basic information of stocks.')
-@click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
-@click.option('-m', '--market', 'markets', metavar='MARKET', multiple=True, type=click.Choice(market_codes, case_sensitive=False), help='Stock market code to get. Alternative to --code. Can set multiple times.')
-@click.option('-i', '--input', metavar='FILENAME', type=click.Path(), help='Text or excel file containing codes. Alternative to --code or --market.')
+@click.option('-c', '--code', metavar='CODE', help='Stock code to get.')
 @click.option('-o', '--output', metavar='FILENAME', type=click.Path(), help="Output filename. Optional for single code (prints to console).")
 @click.option('-f', '--format', metavar='FORMAT', type=click.Choice(['md', 'xlsx', 'json'], case_sensitive=False))
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def stockinfo(codes, markets, input, output, format, port, verbose): # pylint: disable=redefined-builtin
-    """
-    \b
-    Possible market codes are:
-      0 : 장내
-      10 : 코스닥
-      3 : ELW
-      8 : ETF
-      50 : KONEX
-      4 : 뮤추얼펀드
-      5 : 신주인수권
-      6 : 리츠
-      9 : 하이얼펀드
-      30 : K-OTC
+def stockinfo(code, output, format, port, verbose): # pylint: disable=redefined-builtin
 
-    \b
-    Possible market code aliases are:
-      all: All possible market codes.
-    """
-
-    if (codes, markets, input, output) == (tuple(), tuple(), None, None):
+    if (code, output) == (None, None):
         fail_with_usage()
 
     set_verbosity(verbose)
 
-    codes_from_input = False
-    codes_len = len(codes)
-
-    if codes_len == 0 and len(markets) == 0:
-        if input is None:
-            fail_with_usage('Cannot specify codes.')
-        if not os.path.exists(input):
-            fail_with_usage('Given input does not exist.')
-
-        codes_from_input = True
-
-        if os.path.isfile(input):
-            if input.endswith('.xlsx'):
-                import pandas as pd
-                df = pd.read_excel(input, dtype=str)
-                code_column = '종목코드'
-                if code_column in df:
-                    codes = df[code_column]
-                else:
-                    codes = df.iloc[0]
-                codes_len = len(codes)
-            elif input.endswith('.txt'):
-                with open(input) as f:
-                    codes = [line.strip() for line in f]
-                codes_len = len(codes)
-            else:
-                fail_with_usage('Unrecognized input type.')
-        else:
-            fail_with_usage('Unrecognized input type.')
-
     if output is None:
-        if codes_len > 1 or codes_from_input:
-            fail_with_usage('Output path is not specified.')
         if format is None:
             format = 'md'
     else:
@@ -320,140 +272,53 @@ def stockinfo(codes, markets, input, output, format, port, verbose): # pylint: d
 
     import pandas as pd
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
+        dic = context.GetStockBasicInfoAsDict(code)
+        series = pd.Series(dic)
 
-        if not codes_from_input and codes_len == 1:
-            df = context.GetStockInfoAsDataFrame(codes)
-            if not output:
-                if format == 'md':
-                    click.echo(df.iloc[0].to_markdown())
-                elif format == 'json':
-                    click.echo(df.iloc[0].to_json())
-            else:
-                if format == 'xlsx':
-                    df.to_excel(output, index=False)
-                elif format == 'json':
-                    with open(output, 'w') as f:
-                        click.echo(df.iloc[0].to_json(), file=f)
-        elif codes_len > 0:
-            df = context.GetStockInfoAsDataFrame(codes)
-            df.to_excel(output, index=False)
-        elif len(markets) > 0:
-            if 'all' in markets:
-                markets = market_codes
-            if format == 'xlsx':
-                with pd.ExcelWriter(output) as writer: # pylint: disable=abstract-class-instantiated
-                    for market in markets:
-                        codes = context.GetCodeListByMarketAsList(market)
-                        df = context.GetStockInfoAsDataFrame(codes)
-                        df.to_excel(writer, index=False, sheet_name=market)
+        if not output:
+            if format == 'md':
+                click.echo(series.to_markdown())
             elif format == 'json':
-                codes = set()
-                for market in markets:
-                    codes = codes.union(set(context.GetCodeListByMarketAsList(market)))
-                codes = sorted(list(codes))
-                with open(output, 'w', encoding='utf-8') as f:
-                    for code in codes:
-                        df = context.GetStockInfoAsDataFrame(code)
-                        click.echo(df.iloc[0].to_json(), file=f)
+                click.echo(series.to_json())
         else:
-            fail_with_usage('Cannot specify codes.')
+            if format == 'xlsx':
+                series.to_excel(output, header=False)
+            elif format == 'json':
+                with open(output, 'w') as f:
+                    click.echo(series.to_json(), file=f)
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get daily OHLCV of stocks.')
-@click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
-@click.option('-i', '--input', metavar='FILENAME', type=click.Path(), help='Text or excel file containing codes. Alternative to --codes option.')
-@click.option('-o', '--output', metavar='FOLDER|FILENAME', type=click.Path(), help='Output foldername or filename for single code. Files inside the folder would be named as CODE.xlsx. Defaults to current directory.')
+@click.option('-c', '--code', metavar='CODE', help='Stock code to get.')
+@click.option('-o', '--output', metavar='FILENAME', type=click.Path(), help='Output filename for code.')
 @click.option('-f', '--format', metavar='FORMAT', type=click.Choice(['xlsx', 'sqlite3'], case_sensitive=False), default='xlsx', help='Output format. (default: xlsx)')
-@click.option('-x', '--clean', is_flag=True, help='Remove untracked files.')
 @click.option('-s', '--start-date', metavar='YYYY-MM-DD', type=click.DateTime(formats=['%Y-%m-%d', '%Y%m%d']), help='Most recent date to get. Defaults to today or yesterday if market is open.')
 @click.option('-e', '--end-date', metavar='YYYY-MM-DD', type=click.DateTime(formats=['%Y-%m-%d', '%Y%m%d']), help='Stops if reached, not included (optional).')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def daily(codes, input, output, format, clean, start_date, end_date, port, verbose): # pylint: disable=redefined-builtin
-    if (codes, input, output, start_date, end_date) == (tuple(), None, None, None, None):
+def daily(code, output, format, start_date, end_date, port, verbose): # pylint: disable=redefined-builtin
+    if (code, output, start_date, end_date) == (None, None, None, None):
         fail_with_usage()
 
     set_verbosity(verbose)
 
-    codes_len = len(codes)
-    extension = '.' + format
-
-    if codes_len == 0:
-        if input is None:
-            fail_with_usage('Either code or input should be given.')
-        if not os.path.exists(input):
-            fail_with_usage('Given input does not exist.')
-
-        if os.path.isfile(input):
-            if input.endswith('.xlsx'):
-                import pandas as pd
-                df = pd.read_excel(input, dtype=str)
-                code_column = '종목코드'
-                if code_column in df:
-                    codes = df[code_column]
-                else:
-                    codes = df.iloc[0]
-                codes_len = len(codes)
-            elif input.endswith('.txt'):
-                with open(input) as f:
-                    codes = [line.strip() for line in f]
-                codes_len = len(codes)
-            else:
-                fail_with_usage('Unrecognized input file type.')
-        elif os.path.isdir(input):
-            import re
-            codes = [os.path.splitext(name)[0] for name in os.listdir(input) if name.endswith(extension)]
-            codes = [code for code in codes if re.match(r'[0-9A-Z]+', code)]
-            codes_len = len(codes)
-        else:
-            fail_with_usage('Unrecognized input type.')
-
     if output is None:
-        output = '.'
+        output = '%s.%s' % (code, format)
 
-    if os.path.exists(output):
-        if os.path.isdir(output):
-            output_is_folder = True
-        else:
-            output_is_folder = False
-    else:
-        if output.endswith('/') or output.endswith(os.path.sep) or codes_len > 1:
-            output_is_folder = True
-        else:
-            output_is_folder = False
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+        context.EnsureConnected()
+        df = context.GetDailyStockDataAsDataFrame(code, start_date, end_date)
 
-    if not output_is_folder:
-        assert codes_len == 1
-        code = codes[0]
-        base_output = os.path.basename(output)
-        output = os.path.dirname(output)
-        if not base_output.endswith(extension):
-            base_output += extension
-        final_output = os.path.join(output, base_output)
-        def post_process(updater, codes, output, context): # pylint: disable=unused-argument
-            os.replace(updater.get_filepath_for_code(code), final_output)
-    else:
-        def post_process(updater, codes, output, context): # pylint: disable=unused-argument
-            pass
-
-    import contextlib
-
-    with contextlib.ExitStack() as stack:
-        context = None
-
-        if port is not None:
-            from koapy import KiwoomOpenApiContext
-            context = stack.enter_context(KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose))
-            context.EnsureConnected()
-
-        from koapy.data.HistoricalStockPriceDataUpdater import HistoricalStockPriceDataUpdater
-
-        updater = HistoricalStockPriceDataUpdater(codes, output, 'daily', 1, format, delete_remainings=clean, context=context)
-        updater.update()
-        post_process(updater, codes, output, context)
+    if format == 'xlsx':
+        df.to_excel(output)
+    elif format == 'sqlite3':
+        from sqlalchemy import create_engine
+        engine = create_engine('sqlite:///' + output)
+        df.to_sql('A' + code, engine)
 
 minute_intervals = [
     '1',
@@ -467,18 +332,16 @@ minute_intervals = [
 ]
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get minute OHLCV of stocks.')
-@click.option('-c', '--code', 'codes', metavar='CODE', multiple=True, help='Stock code to get. Can set multiple times.')
+@click.option('-c', '--code', metavar='CODE', help='Stock code to get.')
 @click.option('-t', '--interval', metavar='INTERVAL', type=click.Choice(minute_intervals, case_sensitive=False), help='Minute interval. Possible values are [%s]' % '|'.join(minute_intervals))
-@click.option('-i', '--input', metavar='FILENAME', type=click.Path(), help='Text or excel file containing codes. Alternative to --codes option.')
-@click.option('-o', '--output', metavar='FOLDER|FILENAME', type=click.Path(), help='Output foldername or filename for single code. Files inside the folder would be named as CODE.xlsx. Defaults to current directory.')
+@click.option('-o', '--output', metavar='FILENAME', type=click.Path(), help='Output filename for code.')
 @click.option('-f', '--format', metavar='FORMAT', type=click.Choice(['xlsx', 'sqlite3'], case_sensitive=False), default='xlsx', help='Output format. (default: xlsx)')
-@click.option('-x', '--clean', is_flag=True, help='Remove untracked files.')
 @click.option('-s', '--start-date', metavar="YYYY-MM-DD['T'hh:mm:ss]", type=click.DateTime(formats=['%Y-%m-%d', '%Y%m%d', '%Y-%m-%dT%H:%M:%S', '%Y%m%d%H%M%S']), help='Most recent date to get. Defaults to today or yesterday if market is open.')
 @click.option('-e', '--end-date', metavar="YYYY-MM-DD['T'hh:mm:ss]", type=click.DateTime(formats=['%Y-%m-%d', '%Y%m%d', '%Y-%m-%dT%H:%M:%S', '%Y%m%d%H%M%S']), help='Stops if reached, not included (optional).')
 @click.option('-p', '--port', metavar='PORT', help='Port number of grpc server (optional).')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def minute(codes, interval, input, output, format, clean, start_date, end_date, port, verbose): # pylint: disable=redefined-builtin
-    if (codes, interval, input, output, start_date, end_date) == (tuple(), None, None, None, None, None):
+def minute(code, interval, output, format, start_date, end_date, port, verbose): # pylint: disable=redefined-builtin
+    if (code, interval, output, start_date, end_date) == (None, None, None, None, None):
         fail_with_usage()
 
     set_verbosity(verbose)
@@ -486,88 +349,25 @@ def minute(codes, interval, input, output, format, clean, start_date, end_date,
     if interval is None:
         fail_with_usage('Interval is not set.')
 
-    codes_len = len(codes)
-    extension = '.' + format
-
-    if codes_len == 0:
-        if input is None:
-            fail_with_usage('Either code or input should be given.')
-        if not os.path.exists(input):
-            fail_with_usage('Given input does not exist.')
-
-        if os.path.isfile(input):
-            if input.endswith('.xlsx'):
-                import pandas as pd
-                df = pd.read_excel(input, dtype=str)
-                code_column = '종목코드'
-                if code_column in df:
-                    codes = df[code_column]
-                else:
-                    codes = df.iloc[0]
-                codes_len = len(codes)
-            elif input.endswith('.txt'):
-                with open(input) as f:
-                    codes = [line.strip() for line in f]
-                codes_len = len(codes)
-            else:
-                fail_with_usage('Unrecognized input file type.')
-        elif os.path.isdir(input):
-            import re
-            codes = [os.path.splitext(name)[0] for name in os.listdir(input) if name.endswith(extension)]
-            codes = [code for code in codes if re.match(r'[0-9A-Z]+', code)]
-            codes_len = len(codes)
-        else:
-            fail_with_usage('Unrecognized input type.')
-
     if output is None:
-        output = '.'
+        output = '%s.%s' % (code, format)
 
-    if os.path.exists(output):
-        if os.path.isdir(output):
-            output_is_folder = True
-        else:
-            output_is_folder = False
-    else:
-        if output.endswith('/') or output.endswith(os.path.sep) or codes_len > 1:
-            output_is_folder = True
-        else:
-            output_is_folder = False
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+        context.EnsureConnected()
+        df = context.GetMinuteStockDataAsDataFrame(code, interval, start_date, end_date)
 
-    if not output_is_folder:
-        assert codes_len == 1
-        code = codes[0]
-        base_output = os.path.basename(output)
-        output = os.path.dirname(output)
-        extension = '.' + format
-        if not base_output.endswith(extension):
-            base_output += extension
-        final_output = os.path.join(output, base_output)
-        def post_process(updater, codes, output, context): # pylint: disable=unused-argument
-            os.replace(updater.get_filepath_for_code(code), final_output)
-    else:
-        def post_process(updater, codes, output, context): # pylint: disable=unused-argument
-            pass
-
-    import contextlib
-
-    with contextlib.ExitStack() as stack:
-        context = None
-
-        if port is not None:
-            from koapy import KiwoomOpenApiContext
-            context = stack.enter_context(KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose))
-            context.EnsureConnected()
-
-        from koapy.data.HistoricalStockPriceDataUpdater import HistoricalStockPriceDataUpdater
-
-        updater = HistoricalStockPriceDataUpdater(codes, output, 'minute', interval, format, delete_remainings=clean, context=context)
-        updater.update()
-        post_process(updater, codes, output, context)
+    if format == 'xlsx':
+        df.to_excel(output)
+    elif format == 'sqlite3':
+        from sqlalchemy import create_engine
+        engine = create_engine('sqlite:///' + output)
+        df.to_sql('A' + code, engine)
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get TR info.')
 @click.option('-t', '--trcode', 'trcodes', metavar='TRCODE', multiple=True, help='TR code to get (like opt10001).')
 def trinfo(trcodes):
-    from koapy.openapi.TrInfo import TrInfo
+    from koapy import KiwoomOpenApiPlusTrInfo
 
     def get_codes():
         if trcodes:
@@ -591,7 +391,7 @@ def trinfo(trcodes):
                     break
 
     for trcode in get_codes():
-        trinfo = TrInfo.get_trinfo_by_code(trcode)
+        trinfo = KiwoomOpenApiPlusTrInfo.get_trinfo_by_code(trcode)
         if trinfo is not None:
             click.echo('[%s] : [%s]' % (trinfo.tr_code.upper(), trinfo.name))
             click.echo('  [INPUT]')
@@ -611,7 +411,7 @@ def trinfo(trcodes):
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get real type info.')
 @click.option('-t', '--realtype', 'realtypes', metavar='REALTYPE', multiple=True, help='Real type name to get (like 주식시세).')
 def realinfo(realtypes):
-    from koapy.openapi.RealType import RealType
+    from koapy import KiwoomOpenApiPlusRealType
 
     def get_realtypes():
         if realtypes:
@@ -635,9 +435,9 @@ def realinfo(realtypes):
                     break
 
     for realtype in get_realtypes():
-        fids = RealType.get_fids_by_realtype(realtype)
+        fids = KiwoomOpenApiPlusRealType.get_fids_by_realtype(realtype)
         if fids:
-            names = [RealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
+            names = [KiwoomOpenApiPlusRealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
             for fid, name in zip(fids, names):
                 click.echo('  [%s] = %s' % (fid, name))
         else:
@@ -646,10 +446,8 @@ def realinfo(realtypes):
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get market holidays.')
 @click.option('-o', '--output', metavar='FILENAME', type=click.Path(), help='Output filename. (optional)')
 @click.option('-O', '--offline', is_flag=True, help='Do not use krx marketdata api. (default: false)')
-@click.option('-u', '--update', is_flag=True, help='Update local cache, download from krx marketdata api.')
-@click.option('-U', '--no-update', is_flag=True, help='Disable update.')
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
-def holidays(output, offline, update, no_update, verbose):
+def holidays(output, offline, verbose):
     set_verbosity(verbose)
 
     if output is None:
@@ -670,10 +468,10 @@ def holidays(output, offline, update, no_update, verbose):
             def get_holidays_as_dict():
                 holidays = get_holidays()
                 response = {'block1': [{
-                    'calnd_dd_dy': dt.strftime('%Y-%m-%d'),
-                    'kr_dy_tp': dt.strftime('%a'),
-                    'dy_tp_cd': dt.strftime('%a'),
-                    'holdy_nm': name,
+                    'calnd_dd': dt.strftime('%Y-%m-%d'),
+                    'kr_dy_tp': dt.strftime('%A'),
+                    'dy_tp_cd': dt.strftime('%A'),
+                    'holdy_eng_nm': name,
                 } for dt, name in holidays.items() if dt.weekday() < 5]}
                 return response
             response = get_holidays_as_dict()
@@ -686,9 +484,9 @@ def holidays(output, offline, update, no_update, verbose):
             columns = ['date', 'day of week', 'comment']
         data = []
         for holiday in response['block1']:
-            date = holiday['calnd_dd_dy']
+            date = holiday['calnd_dd']
             day = holiday[day_key].strip()
-            name = holiday['holdy_nm']
+            name = holiday['holdy_eng_nm']
             data.append([date, day, name])
         df = pd.DataFrame.from_records(data, columns=columns)
         click.echo(df.to_markdown())
@@ -698,8 +496,6 @@ def holidays(output, offline, update, no_update, verbose):
             if output and not output.endswith('.xls'):
                 output += '.xls'
             download_holidays_as_excel(output)
-            if update:
-                logging.warning('Cannot update on file output.')
         else:
             fail_with_usage('Saving to file should come with offline option disabled.')
 
@@ -710,9 +506,9 @@ def userinfo(port, verbose):
     set_verbosity(verbose)
 
     import pandas as pd
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
 
         result = {}
@@ -747,9 +543,9 @@ def deposit(account, port, verbose):
     if account is None:
         logging.info('Account not given. Using first account available.')
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
 
         if account is None:
@@ -781,9 +577,9 @@ def evaluation(account, include_delisted, exclude_delisted, for_each, as_summary
     elif for_each:
         lookup_type = '2'
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
 
         if account is None:
@@ -842,9 +638,9 @@ def orders(account, date, reverse, executed_only, not_executed_only, stock_only,
     if buy_only:
         order_type = '2'
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
         if account is None:
             account = context.GetFirstAvailableAccount()
@@ -865,8 +661,8 @@ def orders(account, date, reverse, executed_only, not_executed_only, stock_only,
 @click.option('-v', '--verbose', count=True, help='Verbosity.')
 def modulepath(port, verbose):
     set_verbosity(verbose)
-    from koapy import KiwoomOpenApiContext
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         click.echo(context.GetAPIModulePath())
 
 @get.command(context_settings=CONTEXT_SETTINGS, short_help='Get error message for error code.')
@@ -921,8 +717,8 @@ def watch(codes, input, fids, realtype, output, format, port, verbose):
             fail_with_usage('Unrecognized input type.')
 
     if realtype is not None:
-        from koapy.openapi.RealType import RealType
-        fids_from_realtype = RealType.get_fids_by_realtype(realtype)
+        from koapy import KiwoomOpenApiPlusRealType
+        fids_from_realtype = KiwoomOpenApiPlusRealType.get_fids_by_realtype(realtype)
         fids = list(set(fids).union(set(fids_from_realtype)))
 
     if not codes:
@@ -934,12 +730,12 @@ def watch(codes, input, fids, realtype, output, format, port, verbose):
     import datetime
     import pandas as pd
 
-    from koapy import KiwoomOpenApiContext
-    from koapy.openapi.RealType import RealType
+    from koapy import KiwoomOpenApiPlusEntrypoint
+    from koapy import KiwoomOpenApiPlusRealType
 
     def parse_message(message):
         fids = event.single_data.names
-        names = [RealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
+        names = [KiwoomOpenApiPlusRealType.Fid.get_name_by_fid(fid, str(fid)) for fid in fids]
         values = event.single_data.values
         dic = dict((name, value) for fid, name, value in zip(fids, names, values) if name != fid)
         series = pd.Series(dic)
@@ -956,7 +752,7 @@ def watch(codes, input, fids, realtype, output, format, port, verbose):
             click.echo('[%s]' % datetime.datetime.now(), file=output)
             click.echo(parse_message(message).to_markdown(), file=output)
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
 
         for event in context.GetRealDataForCodesAsStream(codes, fids, infer_fids=True):
@@ -1041,7 +837,7 @@ def order(request_name, screen_no, account_no, order_type, code, quantity, price
 
     set_verbosity(verbose)
 
-    from koapy import KiwoomOpenApiContext
+    from koapy import KiwoomOpenApiPlusEntrypoint
     from google.protobuf.json_format import MessageToDict
 
     if format == 'json':
@@ -1054,7 +850,7 @@ def order(request_name, screen_no, account_no, order_type, code, quantity, price
         def print_message(message):
             click.echo(pp.pformat(MessageToDict(message)))
 
-    with KiwoomOpenApiContext(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
+    with KiwoomOpenApiPlusEntrypoint(port=port, client_check_timeout=client_check_timeout, verbosity=verbose) as context:
         context.EnsureConnected()
 
         if order_type in ['3', '4'] and (account_no is None or code is None):
